@@ -3,6 +3,7 @@ import pathlib
 import time
 import os
 import json
+import re
 import shutil
 import subprocess
 import unittest
@@ -82,13 +83,13 @@ def make_dir(filepath):
     except FileExistsError:
         pass
 
-def write_config(filepath, parser):
+def write_config(filepath=None, parser=None):
     "Write Config Parameters to filepath"
     make_dir(filepath)
     with open(filepath, "w") as configfile:
         parser.write(configfile)
 
-def write_file(filepath, data):
+def write_file(filepath=None, data=None):
     "Write Credentials to filepath"
     filepath = filepath.replace('\\', '/')
     make_dir(filepath)
@@ -124,6 +125,39 @@ def to_camel_case(text):
 def get_commit_message():
     return input("Enter commit message: ")
 
+def pyproject():
+    return 'pyproject.toml'
+
+def get_pyproject():
+    with open(pyproject()) as file:
+        return file.read()
+
+def semantic_version_pattern():
+    return r'version\s+=\s+"(\d+[.]\d+[.])(\d+)"'
+
+def get_pyproject_version(text):
+    return re.search(
+        semantic_version_pattern(),
+        text
+    ).group(1, 2)
+
+def update_pyproject_version():
+    text = get_pyproject()
+    version, patch = get_pyproject_version(text)
+    write_file(
+        filepath=pyproject(),
+        data=re.sub(
+            semantic_version_pattern(),
+            f'version="{version}{int(patch)+1}"',
+            text
+        )
+    )
+
 def git_push():
-    os.system(f'git commit -am "{get_commit_message()}"')
-    os.system('git push')
\ No newline at end of file
+    try:
+        update_pyproject_version()
+    except FileNotFoundError:
+        pass
+    finally:
+        os.system(f'git commit -am "{get_commit_message()}"')
+        os.system('git push')
\ No newline at end of file
